FlexGet Web UI (v2)
=======

The Flexget WebUI is currently being rewritten in ReactJS. The WebUI has been seperated into it's own repository.

The source code is now available at https://github.com/Flexget/webui
